==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/yangautoprefixlist/rev20160624/list2/DefaultL2.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yangautoprefixlist.rev20160624.list2;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yangautoprefixlist.rev20160624.list2.l2.C1;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of l2.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultL2 extends InnerModelObject 
        implements L2, MultiInstanceObject<L2Keys> {
    protected String k1;
    protected BitSet valueLeafFlags = new BitSet();
    protected C1 c1;

    @Override
    public String k1() {
        return k1;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public C1 c1() {
        return c1;
    }

    @Override
    public void k1(String k1) {
        valueLeafFlags.set(LeafIdentifier.K1.getLeafIndex());
        this.k1 = k1;
    }

    @Override
    public void c1(C1 c1) {
        this.c1 = c1;
    }

    @Override
    public int hashCode() {
        return Objects.hash(k1, valueLeafFlags, c1);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultL2) {
            DefaultL2 other = (DefaultL2) obj;
            return
                Objects.equals(k1, other.k1) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.equals(c1, other.c1);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("k1=" + k1)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("c1=" + c1)
            .toString();
    }


    /**
     * Creates an instance of defaultL2.
     */
    public DefaultL2() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yangautoprefixlist/rev20160624/list2/DefaultL2.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yangautoprefixlist.rev20160624.list2;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yangautoprefixlist.rev20160624.list2.l2.C1;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of l2.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultL2 extends InnerModelObject 
        implements L2, MultiInstanceObject<L2Keys> {
    protected String k1;
    protected BitSet valueLeafFlags = new BitSet();
    protected C1 c1;

    @Override
    public String k1() {
        return k1;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public C1 c1() {
        return c1;
    }

    @Override
    public void k1(String k1) {
        valueLeafFlags.set(LeafIdentifier.K1.getLeafIndex());
        this.k1 = k1;
    }

    @Override
    public void c1(C1 c1) {
        this.c1 = c1;
    }

    @Override
    public int hashCode() {
        return Objects.hash(k1, valueLeafFlags, c1);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultL2) {
            DefaultL2 other = (DefaultL2) obj;
            return
                Objects.deepEquals(k1, other.k1) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.deepEquals(c1, other.c1);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("k1=" + k1)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("c1=" + c1)
            .toString();
    }


    /**
     * Creates an instance of defaultL2.
     */
    public DefaultL2() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
